@@ -167,15 +167,8 @@ plsda <- function(x, c, ncomp = min(nrow(x) - 1, ncol(x), 20), center = TRUE, sc
    colnames(y) <- classnames
    rownames(y) <- rownames(x)
 
-   # exclude columns if "exclcols" is provided
-   if (length(exclcols) > 0) {
-      x <- mda.exclcols(x, exclcols)
-   }
-
-   # exclude rows if "exclrows" is provided
-   if (length(exclrows) > 0) {
-      x <- mda.exclrows(x, exclrows)
-   }
+   # check calibration data and process excluded rows and columns
+   x <- prepCalData(x, exclrows = exclrows, exclcols = exclcols, min.nrows = 2, min.ncols = 1)
 
    # build a model and apply to calibration set
    model <- pls.cal(x, y, ncomp, center = center, scale = scale, method = method)
